"""Top-level package for kubify."""

__author__ = "kubify"
__email__ = "w@kubify.com"
__version__ = "9004.0.0"
